import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef } from 'react';
import { isParentNode, isJsonError } from 'headless-json-editor';
import { WidgetError } from './WidgetError';
import { WidgetDescription } from './WidgetDescription';
import classNames from 'classnames';
/**
 * container for root of a widget
 */
export const WidgetField = forwardRef(function WidgetField({ widgetType, node, options, children, errors, additionalError, showDescription, showError, className, style }, ref) {
    const listOfErrors = Array.isArray(errors) ? errors : node.errors;
    const parentNode = isParentNode(node);
    const schemaType = node.schema.type;
    const hasError = listOfErrors.length > 0 || isJsonError(additionalError);
    const { disabled = false } = options;
    return (_jsxs("div", { className: classNames('rje-field', `rje-field--${parentNode ? 'parent' : 'value'}`, Array.isArray(schemaType) ? schemaType.map((type) => `rje-field--${type}`) : `rje-field--${schemaType}`, `rje-field--${widgetType}`, disabled ? 'rje-field--disabled' : 'rje-field--enabled', hasError ? ' rje-field--error' : 'rje-field--valid', className, options.classNames), "data-type": schemaType, "data-id": node.pointer, style: style, ref: ref, children: [children, showError !== false && _jsx(WidgetError, { errors: additionalError ? [additionalError] : listOfErrors }), showDescription !== false && _jsx(WidgetDescription, { children: options.description })] }));
});
WidgetField.Header = WidgetFieldHeader;
WidgetField.Error = WidgetError;
WidgetField.Description = WidgetDescription;
function WidgetFieldHeader({ children }) {
    if (children == null) {
        return null;
    }
    return _jsx("div", { className: "rje-field__header", children: children });
}
//# sourceMappingURL=WidgetField.js.map