import { Node } from 'headless-json-editor';
import { ReactNode } from 'react';
import { Editor } from './Editor';
type AnyOption = Record<string, unknown>;
export type WidgetProps<T extends Node = Node> = {
    node: T;
    editor: Editor;
    options?: Partial<T['options']>;
};
/**
 * interface of generic json editor component.
 * it takes the current editor and the current node along with a localized option interface
 */
export type Widget<NodeType extends Node = Node> = (props: WidgetProps<NodeType>) => ReactNode | null;
/**
 * props of your decorated editor
 */
export type DecoratedWidgetProps<NodeType extends Node, ValueType = unknown> = {
    node: NodeType;
    editor: Editor;
    options: NodeType['options'];
    setValue: (value: ValueType) => void;
};
/**
 * interface to your decorated editor
 */
export type DecoratedWidget<NodeType extends Node, ValueType = unknown> = (props: DecoratedWidgetProps<NodeType, ValueType>) => ReactNode | null;
/**
 * add setValue helper to editor component and reduce update cycles
 */
export declare function widget<NodeType extends Node = Node, ValueType = unknown>(WidgetComponent: DecoratedWidget<NodeType, ValueType>): import("react").MemoExoticComponent<(props: WidgetProps<NodeType>) => ReactNode>;
export type WidgetPlugin<N extends Node = any> = {
    readonly id: string;
    use: (node: Node, options?: AnyOption) => boolean;
    Widget: Widget<N>;
};
export {};
