var _a;
import { useState, useEffect } from 'react';
import { OnChangePlugin, deepEqual } from 'headless-json-editor';
import { Editor } from './Editor';
import { useEditorPlugin } from './useEditorPlugin';
// prevent required tooltip in browsers
(_a = document === null || document === void 0 ? void 0 : document.addEventListener) === null || _a === void 0 ? void 0 : _a.call(document, 'invalid', (e) => e.preventDefault(), true);
/**
 * add json editor widget capabilities to your functional component
 */
export function useEditor(settings) {
    const { schema, data, cacheKey } = settings;
    // track instance
    const [editor, setEditor] = useState(null);
    // track current data
    const setCurrentData = useState(data !== null && data !== void 0 ? data : null)[1];
    // track previous inputs - set data to editor if input values have changed
    const [previousData, setPreviousData] = useState(data);
    const [previousSchema, setPreviousSchema] = useState(schema);
    useEffect(() => {
        const instance = new Editor({
            ...settings,
            schema,
            data,
            plugins: settings.plugins,
            widgets: settings.widgets,
            validate: settings.validate,
            liveUpdate: settings.liveUpdate,
            addOptionalProps: settings.addOptionalProps,
            extendDefaults: settings.extendDefaults,
            draftConfig: settings.draftConfig
        });
        // console.log('create editor', instance.id);
        // store last used input data - prevents an additional rerender where
        // last change is lost. this is required in update loops where input
        // data has changed
        setEditor(instance);
        setPreviousData(data);
        setPreviousSchema(schema);
        return () => {
            instance === null || instance === void 0 ? void 0 : instance.destroy();
            setEditor(null);
        };
    }, 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [cacheKey, setEditor]);
    useEditorPlugin(editor, OnChangePlugin, {
        pluginId: 'InternalOnChange',
        onChange(data, root, editor) {
            setCurrentData(data);
            if (settings.onChange) {
                settings.onChange(data, root, editor);
            }
        }
    });
    if (editor == null) {
        return editor;
    }
    // @todo move data comparisson to editor method
    if (data !== previousData && !deepEqual(data, previousData)) {
        editor.setData(data);
        setPreviousData(data);
    }
    if (schema !== previousSchema && !deepEqual(schema, previousSchema)) {
        editor.setSchema(schema);
        setPreviousSchema(schema);
    }
    return editor;
}
//# sourceMappingURL=useEditor.js.map