import { jsx as _jsx } from "react/jsx-runtime";
import { strict as assert } from 'assert';
import { StrictMode, useEffect, useRef, useState } from 'react';
import { render } from '@testing-library/react';
import { uuid } from '../../../headless-json-editor/src/utils/uuid';
function useRefTest() {
    const ref = useRef(null);
    useEffect(() => {
        ref.current = { id: uuid() };
        return () => {
            ref.current = null;
        };
    }, [ref]);
    return ref.current;
}
function useStateTest() {
    const [instance, setInstance] = useState(null);
    useEffect(() => {
        setInstance({ id: uuid() });
        return () => setInstance(null);
    }, [setInstance]);
    return instance;
}
describe('useEffect', () => {
    describe('useRef', () => {
        it('should not render instance on first call', () => {
            const instanceCalls = [];
            function Form() {
                const editor = useRefTest();
                instanceCalls.push(editor);
                return _jsx("div", { children: editor === null || editor === void 0 ? void 0 : editor.id });
            }
            render(_jsx(Form, {}));
            assert.equal(instanceCalls.length, 1);
            assert(instanceCalls[0] == null);
        });
        it('should not render instance on first call in strict mode', () => {
            const instanceCalls = [];
            function Form() {
                const editor = useRefTest();
                instanceCalls.push(editor);
                return _jsx("div", { children: editor === null || editor === void 0 ? void 0 : editor.id });
            }
            render(_jsx(StrictMode, { children: _jsx(Form, {}) }));
            assert.equal(instanceCalls.length, 2);
            assert(instanceCalls[0] == null);
            assert(instanceCalls[1] == null);
        });
    });
    describe('useState', () => {
        it('should render instance on first call', () => {
            const instanceCalls = [];
            function Form() {
                const editor = useStateTest();
                instanceCalls.push(editor);
                return _jsx("div", { children: editor === null || editor === void 0 ? void 0 : editor.id });
            }
            render(_jsx(Form, {}));
            assert.equal(instanceCalls.length, 2);
            assert(instanceCalls[0] == null);
            assert(instanceCalls[1] != null);
        });
        it('should initially render only twice, even if used multiple times', () => {
            const instanceCalls = [];
            function Form() {
                const editor = useStateTest();
                useStateTest();
                instanceCalls.push(editor);
                return _jsx("div", { children: editor === null || editor === void 0 ? void 0 : editor.id });
            }
            render(_jsx(Form, {}));
            assert.equal(instanceCalls.length, 2);
        });
        it('should render instance on first call in strict mode', () => {
            const instanceCalls = [];
            function Form() {
                const editor = useStateTest();
                instanceCalls.push(editor);
                return _jsx("div", { children: editor === null || editor === void 0 ? void 0 : editor.id });
            }
            render(_jsx(StrictMode, { children: _jsx(Form, {}) }));
            assert.equal(instanceCalls.length, 4);
            assert(instanceCalls[0] == null);
            assert(instanceCalls[1] == null);
            assert(instanceCalls[2] != null);
            assert(instanceCalls[3] != null);
        });
    });
});
//# sourceMappingURL=useEffect.test.js.map